[jboss-cvs] JBossAS SVN: r69170 - branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/compatibility/test.
jboss-cvs-commits at lists.jboss.org
jboss-cvs-commits at lists.jboss.org
Mon Jan 21 09:47:57 EST 2008
Author: csaldanh
Date: 2008-01-21 09:47:57 -0500 (Mon, 21 Jan 2008)
New Revision: 69170
Modified:
branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java
Log:
JBPAPP-545: Changed SerialVersionUIDUnitTestCase to ignore changed org.jfree classes
Modified: branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java 2008-01-21 12:31:30 UTC (rev 69169)
+++ branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java 2008-01-21 14:47:57 UTC (rev 69170)
@@ -100,6 +100,8 @@
"org.jboss.iiop.csiv2.SASCurrentLocalTie",
// Ignore org.jboss.ws
"org.jboss.ws",
+ // JBPAPP-545, ignore org.jfree classes
+ "org.jfree",
// Ignore jgroups issues after the upgrade to 2.4.1
"org.jgroups"
};
@@ -175,7 +177,9 @@
"org.jboss.iiop.csiv2.SASCurrentLocalTie",
// Ignore org.jboss.ws
"org.jboss.ws",
- // Ignore jgroups issues after the upgrade to 2.4.1
+ // JBPAPP-545, ignore org.jfree classes
+ "org.jfree",
+ // Ignore jgroups issues after the upgrade to 2.4.1
"org.jgroups",
// Ignore incompatible classes from the sun-javamail upgrade, JBAS-3488
"com.sun.mail.imap.protocol.IMAPAddress",
@@ -249,7 +253,9 @@
"org.jboss.tm.iiop._TransactionFactoryExtStub",
"org.jboss.tm.iiop._TransactionServiceStub",
"org.jboss.iiop.csiv2.SASCurrentLocalTie",
- // Ignore jgroups issues after the upgrade to 2.4.1
+ // JBPAPP-545, ignore org.jfree classes
+ "org.jfree",
+ // Ignore jgroups issues after the upgrade to 2.4.1
"org.jgroups",
// The aop classes were not finalized until 4.0.3
"org.jboss.aop",
@@ -328,6 +334,8 @@
// Ignore org.jboss.webservice for 4.0.1 since the org.apache.axis to
// org.jboss.axis package name change breaks serialization
"org.jboss.webservice",
+ // JBPAPP-545, ignore org.jfree classes
+ "org.jfree",
// Ignore org.hsqldb as there are some utility classes that changed
// in the upgrade to 1_8_0
"org.hsqldb",
@@ -415,6 +423,8 @@
// Ignore org.jboss.webservice for 4.0.1 since the org.apache.axis to
// org.jboss.axis package name change breaks serialization
"org.jboss.webservice",
+ // JBPAPP-545, ignore org.jfree classes
+ "org.jfree",
// Ignore org.hsqldb as there are some utility classes that changed
// in the upgrade to 1_8_0
"org.hsqldb",
More information about the jboss-cvs-commits
mailing list